# -*- coding: utf-8 -*-
# License: GPL-2.0+ <http://spdx.org/licenses/GPL-2.0+>
"""
Generate a logger for a module
"""
from __future__ import absolute_import
import sys
import os
import logging
import logging.handlers
import traceback
import time
import getpass


_fmt_full = '[%(name)s:%(filename)s:%(lineno)d] '\
            '%(asctime)s %(levelname)-7s %(message)s'
_fmt_simple = '[%(name)s] %(asctime)s %(levelname)-7s %(message)s'
_datefmt_full = '%Y-%m-%d %H:%M:%S'
_datefmt_simple = '%H:%M:%S'
_formatter_full = logging.Formatter(fmt=_fmt_full, datefmt=_datefmt_full)
_formatter_simple = logging.Formatter(fmt=_fmt_simple, datefmt=_datefmt_simple)
# set logging time to UTC/GMT
_formatter_full.converter = time.gmtime
_formatter_simple.converter = time.gmtime

def get_logger(name, filelog_path=None, loglevel=None):
    """
    Generate a logger for a module
    """
    logger = logging.getLogger(name)
    logger.propagate = False
    logger.setLevel(logging.INFO)
    console_handler = logging.StreamHandler()
    #console_handler.setLevel(logging.ERROR)
    if filelog_path is None:
        filelog_path = os.path.join('/tmp', 'fedora-autotest-%s.log' % time.strftime("%Y%m%d%H"))

    file_handler = logging.FileHandler(filelog_path, encoding='UTF-8')
    file_handler.setFormatter(_formatter_full)

    console_handler.setFormatter(_formatter_full)
    logger.addHandler(console_handler)
    logger.addHandler(file_handler)
    return logger
